import QtQuick 1.1
import com.nokia.meego 1.0
import 'components' as Components

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait
    property string name: "BackgroundPage.qml"

    property alias mBody: mBody.source
    property alias mEars: mEars.source
    property alias mHead: mHead.source
    property alias mEyes: mEyes.source
    property alias mMouth: mMouth.source
    property alias mLegs: mLegs.source
    property alias mHands: mHands.source
    property alias mAccessories: mAccessories.source
    property alias mAccX: mAccessories.x
    property alias mAccY: mAccessories.y


    Components.Background { id: bg }

    Image {
        id: monstarBg
        width: 480; height: 854
        anchors.centerIn: parent

        function refresh() {
            if (footerView.selectedCategory == 0) {
                source = ""
            } else {

                var path = "resources/parts/background/bg"
                path += footerView.selectedCategory
                path += "/bg-" + colorView.selectedColor + ".png"

                //                console.log(path)
                monstarBg.source = path

            }

        }

    }



    /////////////////////
    // Monstar
    /////////////////////

    Image {
        id: shadowImg
        width: 350; height: 66
        source: "images/shadow.png"
        smooth: true
        anchors {

            horizontalCenter: parent.horizontalCenter
            bottom: mLegs.bottom
            bottomMargin: -61
        }


    }


    // Legs
    Image {
        id: mLegs
        width: 230; height: 230
        anchors {
            verticalCenterOffset: 67
            centerIn: parent
        }
        //source: "resources/parts/monstar1/leg-1.png"
        smooth: true
        scale: 1.3
    }

    // Hands
    Image {
        id: mHands
        width: 240; height: 240
        anchors {
            verticalCenterOffset: 20
            centerIn: parent
        }
        // source: "resources/parts/monstar1/hand-1.png"
        smooth: true
        scale: 1.3
    }

    // Body
    Image {
        id: mBody
        width: 240; height: 240
        anchors {
            verticalCenterOffset: 57
            centerIn: parent
        }
        // source: "resources/parts/monstar1/body-1.png"
        smooth: true
        scale: 1.3
    }

    // Ears
    Image {
        id: mEars
        width: 240; height: 240
        anchors {
            verticalCenterOffset: -100
            centerIn: parent
        }
        // source: "resources/parts/monstar1/ear-1.png"
        smooth: true
        scale: 1.3
    }

    // Head
    Image {
        id: mHead
        width: 240; height: 240
        anchors {
            verticalCenterOffset: -100
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/head-1.png"
        smooth: true
        scale: 1.3
    }

    // Eyes
    Image {
        id: mEyes
        width: 230; height: 230
        anchors {
            verticalCenterOffset: -110
            centerIn: parent
        }
        //source: "resources/parts/monstar1/eye-1.png"
        smooth: true
        scale: 1.3
    }



    // Mouth
    Image {
        id: mMouth
        width: 160; height: 160
        anchors {
            verticalCenterOffset: -65
            centerIn: parent
        }
        //source: "resources/parts/monstar1/mouth-1.png"
        smooth: true
        scale: 1.3
    }

    // Accessories
    Image {
        id: mAccessories
        width: 100; height: 100

        //        source: "resources/parts/accessories/acc1/acc-1.png"
        smooth: true
        scale: 1.3
    }

    ListModel {
        id: colorModel
        //        ListElement { colorimg: "images/selectbgrd/color0.png"}
        ListElement { colorimg: "images/selectbgrd/color1.png"}
        ListElement { colorimg: "images/selectbgrd/color2.png"}
        ListElement { colorimg: "images/selectbgrd/color3.png"}
        ListElement { colorimg: "images/selectbgrd/color4.png"}
        ListElement { colorimg: "images/selectbgrd/color5.png"}
        ListElement { colorimg: "images/selectbgrd/color6.png"}
        ListElement { colorimg: "images/selectbgrd/color7.png"}
        ListElement { colorimg: "images/selectbgrd/color8.png"}
    }



    ListView {
        id: colorView

        property int selectedColor: 1
        signal moved

        anchors {
            top: parent.top
            horizontalCenter: parent.horizontalCenter
            topMargin: 120
        }

        width: 400
        height: 50
        interactive: false

        model: colorModel
        orientation: ListView.Horizontal
        opacity: footerView.selectedCategory == 0 ? 0 : 1
        Behavior on opacity { NumberAnimation { duration: 200 } }

        delegate: Item {
            id: colorItem
            width: 50; height: 50

            Rectangle {
                id: colorSelector
                color: "white"
                opacity: colorView.selectedColor == index + 1 ? 1 : 0
                radius: 10
                width: 49
                height: 49
                anchors.centerIn: parent
            }

            Image {
                id: colorBox
                source: colorimg
                width: 43; height: 43
                anchors.centerIn: parent

            }

            MouseArea {
                anchors.fill: parent
                onClicked: {

                    colorView.selectedColor = index + 1
                    monstarBg.refresh()
                }
            }

        }

    }

    // Footer items
    ListModel {
        id: footerModel
        ListElement { catimg: "images/selectbgrd/bgrd0.png"}
        ListElement { catimg: "images/selectbgrd/bgrd1.png"}
        ListElement { catimg: "images/selectbgrd/bgrd2.png"}
        ListElement { catimg: "images/selectbgrd/bgrd3.png"}
        ListElement { catimg: "images/selectbgrd/bgrd4.png"}
        ListElement { catimg: "images/selectbgrd/bgrd5.png"}
        ListElement { catimg: "images/selectbgrd/bgrd6.png"}
        ListElement { catimg: "images/selectbgrd/bgrd7.png"}
        ListElement { catimg: "images/selectbgrd/bgrd8.png"}
        ListElement { catimg: "images/selectbgrd/bgrd9.png"}
        ListElement { catimg: "images/selectbgrd/bgrd10.png"}
    }
    ListView {
        id: footerView

        property int selectedCategory: 0
        signal moved

        width: 480; height: 120
        anchors {
            bottom: parent.bottom
            horizontalCenter: parent.horizontalCenter
            bottomMargin: 20
        }
        onMovementStarted: footerView.moved()
        model: footerModel
        orientation: ListView.Horizontal

        delegate: Item {
            id: item
            width: 130; height: 119

            Image {
                id: footerImg
                width: 120; height: 120
                anchors.centerIn: parent
                source: catimg
                smooth: true
            }

            MouseArea {
                anchors.fill: parent
                onPressed: item.scale = 0.9
                onReleased: item.scale = 1.0
                onClicked: {
                    footerView.selectedCategory = index
                    monstarBg.refresh()

                }
            }

        }
    }

    Components.HeaderButton {
        id: btnBack
        width: 125; height: 90
        imgNormal: "../images/btn/btn-back.png"
        imgActive: "../images/btn/btn-back-on.png"
        anchors {
            left: parent.left
            leftMargin: 20
            top: parent.top
            topMargin: 10
        }

        onClicked: {
            pageStack.pop()
        }
    }

    Components.HeaderButton {
        id: btnHome
        width: 88; height: 73
        imgNormal: "../images/btn/btn-home.png"
        imgActive: "../images/btn/btn-home.png"
        anchors {
            horizontalCenter: parent.horizontalCenter
            verticalCenter: btnBack.verticalCenter
        }

        onClicked: {
            returnDialog.open()
        }
    }

    Components.HeaderButton {
        id: btnNext
        width: 125; height: 90
        imgNormal: "../images/btn/btn-next.png"
        imgActive: "../images/btn/btn-next-on.png"
        anchors {
            right: parent.right
            rightMargin: 20
            top: parent.top
            topMargin: 10
        }

        onClicked: {
            pageStack.push(Qt.resolvedUrl("CompletionPage.qml"),{
                               mEars: mEars.source,
                               mHead: mHead.source,
                               mEyes: mEyes.source,
                               mBody: mBody.source,
                               mLegs: mLegs.source,
                               mMouth: mMouth.source,
                               mHands: mHands.source,
                               mAccessories: mAccessories.source,
                               mAccX: mAccessories.x,
                               mAccY: mAccessories.y,
                               mBg: monstarBg.source
                           })
        }
    }

}
