import QtQuick 1.1
import com.nokia.meego 1.0
import 'components' as Components
import com.nerdattack.qmlcomponents 1.0

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait
    property string name: "CompletionPage.qml"

    property alias mBody: mBody.source
    property alias mEars: mEars.source
    property alias mHead: mHead.source
    property alias mEyes: mEyes.source
    property alias mMouth: mMouth.source
    property alias mLegs: mLegs.source
    property alias mHands: mHands.source
    property alias mAccessories: mAccessories.source
    property alias mAccX: mAccessories.x
    property alias mAccY: mAccessories.y
    property alias mBg: monstarBg.source

    property string mode: "FULL"

    onStatusChanged: {
        if (status == PageStatus.Activating) {

        }
    }

    onModeChanged: {
        if (mode == "FULL") {

        } else if (mode == "CROP") {

        }
    }


    Components.Background { id: bg }



    Item {
        id: container
        width: 480; height: 854



        /////////////////////
        // Monstar
        /////////////////////

        Item {
            id: monstarContainer

            width: parent.width
            height: parent.height
            anchors.centerIn: parent

            Image {
                id: monstarBg
                property string name: "bg"
                width: 480; height: 854
                anchors.centerIn: parent


            }

            Image {
                id: shadowImg
                width: 350; height: 66
                property string name: "shadow"
                source: "images/shadow.png"
                smooth: true
                anchors {

                    horizontalCenter: parent.horizontalCenter
                    bottom: mLegs.bottom
                    bottomMargin: -61
                }


            }

            // Legs
            Image {
                id: mLegs
                property string name: "legs"
                width: 230; height: 230
                anchors {
                    verticalCenterOffset: 67
                    centerIn: parent
                }
                //source: "resources/parts/monstar1/leg-1.png"
                smooth: true
                scale: 1.3
            }

            // Hands
            Image {
                id: mHands
                property string name: "hands"
                width: 240; height: 240
                anchors {
                    verticalCenterOffset: 20
                    centerIn: parent
                }
                // source: "resources/parts/monstar1/hand-1.png"
                smooth: true
                scale: 1.3
            }

            // Body
            Image {
                id: mBody
                property string name: "body"
                width: 240; height: 240
                anchors {
                    verticalCenterOffset: 57
                    centerIn: parent
                }
                // source: "resources/parts/monstar1/body-1.png"
                smooth: true
                scale: 1.3
            }

            // Ears
            Image {
                id: mEars
                property string name: "ears"
                width: 240; height: 240
                anchors {
                    verticalCenterOffset: -100
                    centerIn: parent
                }
                // source: "resources/parts/monstar1/ear-1.png"
                smooth: true
                scale: 1.3
            }

            // Head
            Image {
                id: mHead
                property string name: "head"
                width: 240; height: 240
                anchors {
                    verticalCenterOffset: -100
                    centerIn: parent
                }
                //        source: "resources/parts/monstar1/head-1.png"
                smooth: true
                scale: 1.3
            }

            // Eyes
            Image {
                id: mEyes
                property string name: "eyes"
                width: 230; height: 230
                anchors {
                    verticalCenterOffset: -110
                    centerIn: parent
                }
                //source: "resources/parts/monstar1/eye-1.png"
                smooth: true
                scale: 1.3
            }





            // Mouth
            Image {
                id: mMouth
                property string name: "mouth"
                width: 160; height: 160
                anchors {
                    verticalCenterOffset: -65
                    centerIn: parent
                }
                //source: "resources/parts/monstar1/mouth-1.png"
                smooth: true
                scale: 1.3
            }

            // Accessories
            Image {
                id: mAccessories
                property string name: "acc"
                width: 100; height: 100

                //        source: "resources/parts/accessories/acc1/acc-1.png"
                smooth: true
                scale: 1.3
            }

            Image {
                id: cropBox
                property string name: "cropbox"
                width: 305; height: 320

                source: "images/cropbox.png"
                x: 60; y: 200
                opacity: page.mode == "CROP" ? 1 : 0
                Behavior on opacity { NumberAnimation { duration: 100 } }

                MouseArea {
                    anchors.fill: parent
                    drag {
                        target: cropBox
                        axis: Drag.XandYAxis
                        minimumX: 20
                        maximumX: 160
                        minimumY: 150
                        maximumY: 400
                    }
                }
            }

        } // monstarContainer





        // Footer items
        ListModel {
            id: footerModel
            ListElement { catimg: "images/save/save-full.png"}
            ListElement { catimg: "images/save/save-cropped.png"}

        }
        ListView {
            id: footerView

            width: 260; height: 120
            anchors {
                bottom: parent.bottom
                horizontalCenter: parent.horizontalCenter
                bottomMargin: 20
            }

            model: footerModel
            orientation: ListView.Horizontal
            interactive: false

            delegate: Item {
                id: item
                width: 130; height: 119

                Image {
                    id: footerImg
                    width: 120; height: 120
                    anchors.centerIn: parent
                    source: catimg
                    smooth: true
                }

                MouseArea {
                    anchors.fill: parent
                    onPressed: item.scale = 0.9
                    onReleased: item.scale = 1.0
                    onClicked: {
                        if (index == 0) { // full
                            page.mode = "FULL"
                        } else if (index == 1) {
                            page.mode = "CROP"
                        }


                    }
                }

            }
        }

        Components.HeaderButton {
            id: btnBack
            width: 125; height: 90
            imgNormal: "../images/btn/btn-back.png"
            imgActive: "../images/btn/btn-back-on.png"
            anchors {
                left: parent.left
                leftMargin: 20
                top: parent.top
                topMargin: 10
            }

            onClicked: {
                pageStack.pop()
            }
        }

        Components.HeaderButton {
            id: btnHome
            width: 88; height: 73
            imgNormal: "../images/btn/btn-home.png"
            imgActive: "../images/btn/btn-home.png"
            anchors {
                horizontalCenter: parent.horizontalCenter
                verticalCenter: btnBack.verticalCenter
            }

            onClicked: {
                returnDialog.open()
            }
        }

        Components.HeaderButton {
            id: btnNext
            width: 125; height: 90
            imgNormal: "../images/btn/btn-next.png"
            imgActive: "../images/btn/btn-next-on.png"
            anchors {
                right: parent.right
                rightMargin: 20
                top: parent.top
                topMargin: 10
            }

            onClicked: {

                if (monstarName.text == "" || monstarName.text == "What's my name?") {

                    infoDialog.open()
                } else {
                    var reset

                    if (monstarBg.source == "") {
                        monstarBg.source = "images/bgrd.png"
                        reset = true
                    }

                    if (page.mode == "FULL")
                        imageHandler.saveMonstar(monstarContainer, monstarName.text, 0)
                    else
                        imageHandler.saveMonstar(monstarContainer, monstarName.text, 1)

                    appWindow.closeDoor("")

                    if (reset == true)
                        monstarBg.source = ""

                }
            }
        }

        // Monstar Name
        TextField {
            id: monstarName
            width: 300
            height: 60
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: btnHome.bottom
                topMargin: 20
            }
            placeholderText: "What's my name?"
            maximumLength: 24

            Keys.onPressed: {
                if (event.key == 16777220) {
                    monstarName.closeSoftwareInputPanel()
                }
            }
        }

        ImageHandler {
            id: imageHandler

            onImageSaved: {
                console.log("Image saved: " + path)

                // save monstar into DB
                var query = "INSERT INTO Monstars (name,filename,mhead,meyes,mbody,mears,mmouth,mlegs,macc,mhands,created) VALUES ('"+
                    escape(monstarName.text) +"','"+
                    escape(path)+"','"+
                    mHead.source +"','"+
                    mEyes.source +"','"+
                    mBody.source +"','"+
                    mEars.source +"','"+
                    mMouth.source +"','"+
                    mLegs.source +"','"+
                    mAccessories.source +"','"+
                    mHands.source +"','"+
                    Date.now()
                    +"')"
                // console.log(query)
                storagedb.query(query)


                var mName = monstarName.text

                pageStack.push(Qt.resolvedUrl("GalleryPage.qml"), {monstarSource: path, monstarName: mName, mode: "PREVIEW"})
            }
        }

        //        Connections {
        //            target: imageHandler

        //            onImageSaved: {
        //                console.log("Image saved: " + path)

        //                // save monstar into DB
        //                storagedb.query("INSERT INTO Monstars (name,filename,mhead,meyes,mbody,mears,mmouth,mlegs,macc,mhands,created) VALUES ('"+
        //                                monstarName.text +"','"+
        //                                path+"','"+
        //                                mHead.source +"','"+
        //                                mEyes.source +"','"+
        //                                mBody.source +"','"+
        //                                mEars.source +"','"+
        //                                mMouth.source +"','"+
        //                                mLegs.source +"','"+
        //                                mAccessories.source +"','"+
        //                                mHands.source +"','"+
        //                                Date.now()
        //                                +"')")


        //                var mName = monstarName.text

        //                pageStack.push(Qt.resolvedUrl("GalleryPage.qml"), {monstarSource: path, monstarName: mName})
        //            }
        //        }


    } // item container


}
