import QtQuick 1.1
import com.nokia.meego 1.0
import 'components' as Components

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait
    property string name: "CreatorPage.qml"


    property bool random: false

    property bool ready: mHead.source == "" &&
                         mBody.source == "" &&
                         mHands.source == "" &&
                         mLegs.source == "" &&
                         mEars.source == "" &&
                         mMouth.source == "" &&
                         mEyes.source == "" &&
                         mAccessories.source == "" ? false : true

    onStatusChanged: {
        if (status == PageStatus.Active) {
            appWindow.openDoor()
        } else if (status == PageStatus.Activating) {
            if (random == true) {
                btnRandom.opacity = 1
                page.random = false
                generateMonstar()
            }
        }
    }

    function generateMonstar() {
        //console.log("Generating random monstar...")

        var m, p

        // head
        m = getRandom(20)
        p = getRandom(8)
        mHead.source = "resources/parts/monstar"+m+"/head-"+p+".png"

        // ears
        m = getRandom(20)
        p = getRandom(8)
        mEars.source = "resources/parts/monstar"+m+"/ear-"+p+".png"

        // body
        m = getRandom(20)
        p = getRandom(8)
        mBody.source = "resources/parts/monstar"+m+"/body-"+p+".png"

        // legs
        m = getRandom(20)
        p = getRandom(8)
        mLegs.source = "resources/parts/monstar"+m+"/leg-"+p+".png"

        // eyes
        m = getRandom(20)
        p = getRandom(8)
        mEyes.source = "resources/parts/monstar"+m+"/eye-"+p+".png"

        // mouth
        m = getRandom(20)
        p = getRandom(8)
        mMouth.source = "resources/parts/monstar"+m+"/mouth-"+p+".png"

        // hands
        m = getRandom(20)
        p = getRandom(8)
        mHands.source = "resources/parts/monstar"+m+"/hand-"+p+".png"

        // accessories
        m = getRandom(20)
        p = getRandom(8)
        mAccessories.source = "resources/parts/accessories/acc"+m+"/acc-"+p+".png"



    }

    function getRandom(range) {
        var randomnumber=Math.floor(Math.random()*range)
        randomnumber++

        return randomnumber

    }

    function resetMonstar() {
        mEars.source = ""
        mHead.source = ""
        mEyes.source = ""
        mHands.source = ""
        mLegs.source = ""
        mAccessories.source = ""
        mBody.source = ""
        mMouth.source = ""
    }

    Components.Background { id: bg }

    Components.HeaderButton {
        id: btnReset
        width: 125; height: 90
        imgNormal: "../images/btn/btn-reset.png"
        imgActive: "../images/btn/btn-reset-on.png"
        anchors {
            left: parent.left
            leftMargin: 20
            top: parent.top
            topMargin: 10
        }

        onClicked: {
            page.resetMonstar()
        }
    }

    Components.HeaderButton {
        id: btnHome
        width: 88; height: 73
        imgNormal: "../images/btn/btn-home.png"
        imgActive: "../images/btn/btn-home.png"
        anchors {
            horizontalCenter: parent.horizontalCenter
            verticalCenter: btnReset.verticalCenter
        }

        onClicked: {
            pageStack.pop(null)
        }
    }

    Components.HeaderButton {
        id: btnNext
        width: 125; height: 90
        imgNormal: "../images/btn/btn-next.png"
        imgActive: "../images/btn/btn-next-on.png"
        anchors {
            right: parent.right
            rightMargin: 20
            top: parent.top
            topMargin: 10
        }

        onClicked: {
            if (page.ready == false) {
                footerAnimation.restart()
            } else {

                pageStack.push(Qt.resolvedUrl("BackgroundPage.qml"),{
                                   mEars: mEars.source,
                                   mHead: mHead.source,
                                   mEyes: mEyes.source,
                                   mBody: mBody.source,
                                   mLegs: mLegs.source,
                                   mMouth: mMouth.source,
                                   mHands: mHands.source,
                                   mAccessories: mAccessories.source,
                                   mAccX: mAccessories.x,
                                   mAccY: mAccessories.y
                               })

            }
        }
    }

    /////////////////////
    // Monstar
    /////////////////////


    Image {
        id: shadowImg
        width: 350; height: 66
        source: "images/shadow.png"
        smooth: true
        anchors {

            horizontalCenter: parent.horizontalCenter
            bottom: mLegs.bottom
            bottomMargin: -61
        }
        opacity: mHead.source != "" ||
                 mBody.source != "" ||
                 mHands.source != "" ||
                 mLegs.source != "" ||
                 mEars.source != "" ||
                 mMouth.source != "" ||
                 mEyes.source != "" ||
                 mAccessories.source != "" ? 1 : 0


    }

    // Legs
    Image {
        id: mLegs
        width: 230; height: 230
        anchors {
            verticalCenterOffset: 66
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/leg-1.png"
        //        source: "resources/monstarsvg/leg.svg"
        smooth: true
        scale: 1.3
    }

    // Hands
    Image {
        id: mHands
        width: 240; height: 240
        anchors {
            verticalCenterOffset: 20
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/hand-1.png"
        //        source: "resources/monstarsvg/hand.svg"
        smooth: true
        scale: 1.3
    }

    // Body
    Image {
        id: mBody
        width: 240; height: 240
        anchors {
            verticalCenterOffset: 57
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/body-1.png"
        //        source: "resources/monstarsvg/body.svg"
        smooth: true
        scale: 1.3

//        MouseArea {
//            anchors.fill: parent
//            onPressAndHold: debugOverlay.opacity = 1
//        }
    }

    // Ears
    Image {
        id: mEars
        width: 240; height: 240
        anchors {
            verticalCenterOffset: -100
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/ear-1.png"
        //        source: "resources/monstarsvg/ear.svg"
        smooth: true
        scale: 1.3
    }

    // Head
    Image {
        id: mHead
        width: 240; height: 240
        anchors {
            verticalCenterOffset: -100
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/head-1.png"
        //        source: "resources/monstarsvg/head.svg"
        smooth: true
        scale: 1.3
    }

    // Eyes
    Image {
        id: mEyes
        width: 230; height: 230
        anchors {
            verticalCenterOffset: -110
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/eye-1.png"
        //        source: "resources/monstarsvg/eye.svg"
        smooth: true
        scale: 1.3
    }



    // Mouth
    Image {
        id: mMouth
        x: 100
        y: 175
        width: 160; height: 160
        anchors.horizontalCenterOffset: 0
        anchors {
            verticalCenterOffset: -65
            centerIn: parent
        }
        //        source: "resources/parts/monstar1/mouth-1.png"
        //        source: "resources/monstarsvg/mouth.svg"
        smooth: true
        scale: 1.3

    }

    // Accessories
    Image {
        id: mAccessories
        width: 100; height: 100
        x: 340; y: 300

        SequentialAnimation {
            id: pulsateAnimation
            loops: Animation.Infinite
            running: false
            NumberAnimation { target: mAccessories; property: "opacity"; from: 1; to: 0.5; duration: 700 }
            NumberAnimation { target: mAccessories; property: "opacity"; from: 0.5; to: 1; duration: 700 }
        }


        //        source: "resources/parts/accessories/acc1/acc-1.png"

        smooth: true
        scale: 1.3

        MouseArea {
            anchors.fill: parent
            drag.target: mAccessories
            drag.axis: Drag.XandYAxis
            drag.minimumX: 25
            drag.maximumX: 355
            drag.minimumY: 100
            drag.maximumY: 550
        }
    }


    Image {
        id: selectArrow
        width: 85; height: 144
        source: "images/arrow.png"
        smooth: true
        opacity: selectText.opacity
        anchors {
            bottom: footerView.top
            left: parent.left
            leftMargin: 35
            bottomMargin: 10
        }

    }

    Text {
        id: selectText
        width: 400
        wrapMode: Text.Wrap
        font {
            pixelSize: 28
            family: visual.fontHand
        }
        horizontalAlignment: Text.AlignHCenter
        color: "white"
        opacity: mHead.source == "" &&
                 mBody.source == "" &&
                 mHands.source == "" &&
                 mLegs.source == "" &&
                 mEars.source == "" &&
                 mMouth.source == "" &&
                 mEyes.source == "" &&
                 btnRandom.opacity == 0 &&
                 mAccessories.source == "" ? 1 : 0


        text: "Click on a Monstar part to get started!"
        anchors {
            bottom: selectArrow.top
            bottomMargin: 10
            left: selectArrow.left
            leftMargin: 10
        }
    }

    SequentialAnimation {
        id: footerAnimation
        running: false
        loops: 2
        NumberAnimation { target: footerView; property: "scale"; from: 1; to: 1.1; duration: 150 }
        NumberAnimation { target: footerView; property: "scale"; from: 1.1; to: 1; duration: 150 }

    }


    // Footer items
    ListModel {
        id: footerModel
        ListElement { catimg: "images/customscreen/part-body.png"; category: "bodies" }
        ListElement { catimg: "images/customscreen/part-head.png"; category: "heads" }
        ListElement { catimg: "images/customscreen/part-eye.png"; category: "eyes" }
        ListElement { catimg: "images/customscreen/part-mouth.png"; category: "mouths" }
        ListElement { catimg: "images/customscreen/part-hand.png"; category: "hands" }
        ListElement { catimg: "images/customscreen/part-legs.png"; category: "legs" }
        ListElement { catimg: "images/customscreen/part-ears.png"; category: "ears" }
        ListElement { catimg: "images/customscreen/part-accessories.png"; category: "accessories" }
    }

    ListView {
        id: footerView

        property string selectedCategory: ""
        signal moved

        width: 480; height: 119
        anchors {
            bottom: parent.bottom
            horizontalCenter: parent.horizontalCenter
            bottomMargin: 20
        }

        model: footerModel
        orientation: ListView.Horizontal
        onMovementStarted: footerView.moved()

        delegate: Item {
            id: item
            width: 100; height: 119

            Component.onCompleted: footerView.moved.connect(item.moved)
            function moved() {
                item.scale = 1.0
            }

            state: footerView.selectedCategory == category ? "ON" : "OFF"

            Image {
                id: selector
                opacity: item.state == "ON" ? 1 : 0
                source: "images/customscreen/selectedpart.png"
                width: 119; height: 119
                anchors.centerIn: parent
                smooth: true
            }

            Image {
                id: footerImg
                width: 65; height: 65
                anchors.centerIn: parent
                source: catimg
                smooth: true
            }

            MouseArea {
                anchors.fill: parent

                onPressed: item.scale = 0.9
                onReleased: item.scale = 1.0

                onClicked: {
                    footerView.selectedCategory = category
                    partsOverlay.selectedCategory = category

                    dataLoader.loadParts(footerView.selectedCategory, partsOverlay.selectedColor)

                }
            }

        }
    }

    Text {
        id: randomText
        text: "Randomize"
        color: 'white'
        font.family: visual.fontHand
        font.pixelSize: 16
        horizontalAlignment: Text.AlignHCenter
        anchors {
            top: btnRandom.bottom
            horizontalCenter: btnRandom.horizontalCenter
        }
        smooth: true
        opacity: btnRandom.opacity
    }

    Components.HeaderButton {
        id: btnRandom
        width: 82; height: 90
        imgNormal: "../images/btn/btn-random.png"
        imgActive: "../images/btn/btn-random.png"

        opacity: 0

        anchors {
            left: parent.left
            leftMargin: 20
            bottom: parent.bottom
            bottomMargin: 170
        }

        onClicked: {
            page.generateMonstar()

        }

        Timer {
            id: hopTimer
            interval: 3000
            repeat: true
            running: true
            onTriggered: {
                hopAnimation.restart()
            }
        }

        SequentialAnimation {
            id: hopAnimation
            running: false
            ParallelAnimation {
                NumberAnimation { target: btnRandom; property: "anchors.bottomMargin"; from: 170; to: 175; duration: 200 }
                NumberAnimation { target: btnRandom; property: "rotation"; from: 0; to: -3; duration: 200 }
            }

            ParallelAnimation {
                NumberAnimation { target: btnRandom; property: "anchors.bottomMargin"; from: 175; to: 170; duration: 200 }
                NumberAnimation { target: btnRandom; property: "rotation"; from: -3; to: 0; duration: 200 }
            }

            ParallelAnimation {
                NumberAnimation { target: btnRandom; property: "anchors.bottomMargin"; from: 170; to: 175; duration: 200 }
                NumberAnimation { target: btnRandom; property: "rotation"; from: 0; to: 3; duration: 200 }
            }

            ParallelAnimation {
                NumberAnimation { target: btnRandom; property: "anchors.bottomMargin"; from: 175; to: 170; duration: 200 }
                NumberAnimation { target: btnRandom; property: "rotation"; from: 3; to: 0; duration: 200 }
            }
        }
    }


    PartsOverlay {
        id: partsOverlay

        onSelectedCategoryChanged: {
            if (selectedCategory == "accessories") {
                pulsateAnimation.restart()
            } else {
                pulsateAnimation.stop()
                mAccessories.opacity = 1
            }
        }

        onPartSelected: {
            switch (selectedCategory) {
            case "heads": {
                mHead.source = uri
            } break;

            case "eyes": {
                mEyes.source = uri
            } break;

            case "ears": {
                mEars.source = uri
            } break;

            case "bodies": {
                mBody.source = uri
            } break;

            case "mouths": {
                mMouth.source = uri
            } break;

            case "hands": {
                mHands.source = uri
            } break;

            case "legs": {
                mLegs.source = uri
            } break;

            case "accessories": {
                mAccessories.source = uri
            } break;

            } // switch

        }
    }

    Connections {
        target: dataLoader

        onPartsLoaded: {
            if (partsOverlay.opacity == 0)
                partsOverlay.opacity = 1
        }
    }

    // for debugging
    DebugOverlay {
        id: debugOverlay

        onOpacityChanged: {
            if (opacity == 1) {
                stuff = "Head: " + mHead.source
                stuff += "\n\nBody: " + mBody.source
                stuff += "\n\nHands: " + mHands.source
                stuff += "\n\nMouth: " + mMouth.source
                stuff += "\n\nLegs: " + mLegs.source
                stuff += "\n\nEyes: " + mEyes.source
                stuff += "\n\nEars: " + mEars.source
                stuff += "\n\nAcc: " + mAccessories.source
            }
        }
    }




}
