import QtQuick 1.1
import com.nokia.meego 1.0
import 'components' as Components
import com.nerdattack.qmlcomponents 1.0

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait
    property string name: "CompletionPage.qml"

    property string mode: "GALLERY"

    clip: true

    property string monstarSource
    property string monstarName

    property int totalMonstars: 0

    function getRandom(range) {
        var randomnumber=Math.floor(Math.random()*range)

        return randomnumber

    }

    function loadMonstars() {
        galleryModel.clear()


        var result = storagedb.query("SELECT * FROM Monstars ORDER BY created DESC")

        page.totalMonstars = result.length

        for (var i=0; i<result.length; i++) {
            galleryModel.append({"uid": result.item(i).id, "name": unescape(result.item(i).name), "filename": unescape(result.item(i).filename)})
        }

        if (result.length == 0)
            monstarCounter.text = "0/0"
        else
            monstarCounter.text = "1/" + page.totalMonstars
    }

    function deleteMonstar(uid) {
        storagedb.query("DELETE FROM Monstars WHERE id=" + uid)
        loadMonstars()
    }

    function currentMonstarImg() {
        var n = galleryView.indexAt(galleryView.contentX + 200, 200)
        var img = galleryModel.get(n).filename
        return img
    }

    onStatusChanged: {
        if (status == PageStatus.Active) {
            doorTimer.restart()
        } else if (status == PageStatus.Activating) {
            if (pageStack.depth < 3)
                btnBack.opacity = 0

            loadMonstars()

        }
    }

    Timer {
        id: doorTimer
        interval: 500
        running: false
        onTriggered: appWindow.openDoor();
    }

    Components.Background { id: bg }

    ListModel {
        id: galleryModel
        ListElement {uid: ""; name: ""; filename: ""}
    }

    ListView {
        id: galleryView



        width: 444; height: 474
        //        clip: true
        anchors {
            centerIn: parent
            horizontalCenterOffset: 10

        }
        orientation: ListView.Horizontal
        snapMode: ListView.SnapOneItem
        model: galleryModel
        cacheBuffer: 1000
        opacity: page.mode == "GALLERY" ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 200 } }

        footer: Item {
            width: 20; height: 408
        }

        onMovementEnded: {
            var current = galleryView.indexAt(galleryView.contentX + 200, 200)
            current++
            monstarCounter.text = current + "/" + page.totalMonstars
        }

        delegate: Item {
            id: item
            width: 424; height: 474
            rotation: page.getRandom(100) > 50 ? 2 : -2

            /////////////////////
            // Monstar Delegate
            /////////////////////


            Image {
                id: monstarImg
                width: 380; height: 380
                smooth: true
                anchors {
                    top: monstarPhoto.top
                    topMargin: 17
                    left: monstarPhoto.left
                    leftMargin: 17
                }
                source: filename
                fillMode: Image.PreserveAspectCrop
                clip: true
                cache: false
            }

            Image {
                id: monstarPhoto

                width: 414; height: 474
                anchors.centerIn: parent
                source: "images/gallery/polaroid.png"
                smooth: true

                Text {
                    id: monstarName
                    text: name
                    font {
                        family: visual.fontHand
                        pixelSize: 28
                    }
                    horizontalAlignment: Text.AlignHCenter

                    anchors {
                        bottom: parent.bottom
                        bottomMargin: 20
                        right: parent.right
                        left: parent.left
                        leftMargin: 10
                        rightMargin: 10
                    }
                    elide: Text.ElideRight
                    smooth: true
                }


            }

        }
    } // ListView

    /////////////////////
    // Monstar Delegate
    /////////////////////


    Image {
        id: previewImg
        width: 380; height: 380
        smooth: true
        anchors {
            top: previewPhoto.top
            topMargin: 17
            left: previewPhoto.left
            leftMargin: 17
        }
        source: page.monstarSource
        fillMode: Image.PreserveAspectCrop
        clip: true
        cache: false
        opacity: page.mode == "PREVIEW" ? 1 : 0
    }

    Image {
        id: previewPhoto

        width: 414; height: 474
        anchors.centerIn: parent
        anchors.horizontalCenterOffset: 5
        source: "images/gallery/polaroid.png"
        smooth: true
        opacity: page.mode == "PREVIEW" ? 1 : 0
        Text {
            id: previewName
            text: page.monstarName
            font {
                family: visual.fontHand
                pixelSize: 28
            }
            horizontalAlignment: Text.AlignHCenter

            anchors {
                bottom: parent.bottom
                bottomMargin: 20
                right: parent.right
                left: parent.left
                leftMargin: 10
                rightMargin: 10
            }
            elide: Text.ElideRight
            smooth: true
        }


    }





    Components.HeaderButton {
        id: btnBack
        width: 125; height: 90
        imgNormal: "../images/btn/btn-back.png"
        imgActive: "../images/btn/btn-back-on.png"

        anchors {
            left: parent.left
            leftMargin: 20
            top: parent.top
            topMargin: 10
        }
        opacity: page.mode == "PREVIEW" ? 1 : 0

        onClicked: {
            imageHandler.deleteMonstar(page.monstarSource)
        }
    }

    ImageHandler {
        id: imageHandler
    }

    Connections {
        target: imageHandler
        onImageDeleted: {
            page.deleteMonstar(galleryModel.get(0).uid)
            pageStack.pop()
        }
    }



    Components.HeaderButton {
        id: btnHome
        width: 88; height: 73
        imgNormal: "../images/btn/btn-home.png"
        imgActive: "../images/btn/btn-home.png"
        anchors {
            horizontalCenter: parent.horizontalCenter
            verticalCenter: btnBack.verticalCenter
        }
        opacity: page.mode == "PREVIEW" ? 1 : 0

        onClicked: {
            returnDialog.open()
        }
    }

    Components.HeaderButton {
        id: btnSave
        width: 125; height: 90
        imgNormal: "../images/btn/btn-save.png"
        imgActive: "../images/btn/btn-save-on.png"
        anchors {
            right: parent.right
            rightMargin: 20
            top: parent.top
            topMargin: 10
        }
        opacity: page.mode == "PREVIEW" ? 1 : 0

        onClicked: {
            flashAnimation.restart()
            page.mode = "GALLERY"
        }
    }


    Components.GalleryButton {
        id: btnReturn
        width: 80; height: 80
        imgNormal: "../images/gallery/btn-back.png"
        imgActive: "../images/gallery/btn-back-on.png"
        smooth: true
        anchors {
            bottom: parent.bottom
            bottomMargin: 40
            right: btnShare.left
            rightMargin: 80
        }
        opacity: page.mode == "GALLERY" ? 1 : 0
        onClicked: pageStack.pop(null)
    }

    Components.GalleryButton {
        id: btnShare
        width: 80; height: 80
        imgNormal: "../images/gallery/btn-share.png"
        imgActive: "../images/gallery/btn-share-on.png"
        smooth: true
        anchors {
            bottom: parent.bottom
            bottomMargin: 40
            horizontalCenter: parent.horizontalCenter
        }
        opacity: page.mode == "GALLERY" ? 1 : 0
        onClicked: {
            var uri = page.currentMonstarImg()
            console.log(uri)
            shareUI.shareFile(uri)
        }


    }

    Components.GalleryButton {
        id: btnDelete
        width: 80; height: 80
        imgNormal: "../images/gallery/btn-delete.png"
        imgActive: "../images/gallery/btn-delete-on.png"
        smooth: true
        anchors {
            bottom: parent.bottom
            bottomMargin: 40
            left: btnShare.right
            leftMargin: 80
        }
        opacity: page.mode == "GALLERY" ? 1 : 0
        onClicked: deleteDialog.open()
    }

    // monstar counter
    Text {
        id: monstarCounter
        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: 140
        }
        horizontalAlignment: Text.AlignHCenter
        font {
            pixelSize: 32
            bold: true
        }
        color: "white"
        smooth: true
        text: "0/0"

        opacity: page.mode == "GALLERY" ? 1 : 0
    }


    Image {
        id: header
        width: 460; height: 95
        source: "images/logo-monstar.png"
        smooth: true
        anchors {
            top: parent.top
            topMargin: 50
            horizontalCenter: parent.horizontalCenter
        }
        opacity: page.mode == "GALLERY" ? 1 : 0
    }

    QueryDialog {
        id: deleteDialog
        message: "Delete this Monstar?"
        titleText: "Confirm Delete"
        acceptButtonText: "YES"
        rejectButtonText: "Cancel"

        onAccepted: {
            var current = galleryView.indexAt(galleryView.contentX + 200, 200)
            var uid = galleryModel.get(current).uid
            //console.log("DELETE " + uid)
            page.deleteMonstar(uid)
            deleteDialog.close()
        }

        onRejected: {
            deleteDialog.close()
        }

        opacity: page.mode == "GALLERY" ? 1 : 0

    }


    Rectangle {
        id: flash
        color: "white"
        anchors.fill: parent
        opacity: 0

    }

    SequentialAnimation {
        id: flashAnimation
        running: false
        NumberAnimation { target: flash; property: "opacity"; from: 0; to: 1; duration: 0 }
        NumberAnimation { target: flash; property: "opacity"; from: 1; to: 0; duration: 1000 }

    }

    MeegoShareUI {
        id: shareUI

    }

    QueryDialog {
        id: returnDialog
        titleText: "Return to Main Menu"
        message: "Are you sure you want to discard this Monstar?"
        acceptButtonText: "YES"
        rejectButtonText: "Cancel"
        onRejected: returnDialog.close()
        onAccepted: {
            console.log("Local cancel")
            imageHandler.deleteMonstar(page.monstarSource)
            page.deleteMonstar(galleryModel.get(0).uid)
            pageStack.pop(null)
        }

    }

}
