import QtQuick 1.1

Item {
    id: container

    property string selectedCategory
    property string catName
    property alias selectedColor: colorView.selectedColor

    property bool enlargeParts: false

    onSelectedCategoryChanged: {
        var n1 = selectedCategory.substring(0,1)
        n1 = n1.toUpperCase()

        var n2 = selectedCategory.substring(1,selectedCategory.length)

        catName = n1 + n2

        if (selectedCategory == "eyes" || selectedCategory == "mouths") {
            enlargeParts = true
        } else {
            enlargeParts = false
        }
    }

    signal partSelected(string uri)

    // width: 480; height: 819
    anchors {
        fill: parent
    }
    opacity: 0

    onOpacityChanged: {
        //if (opacity == 0)
      //      colorView.selectedColor = "red"
    }

    Behavior on opacity { NumberAnimation { duration: 200 } }

    Rectangle {
        id: bg
        anchors.fill: parent
        color: "black"
        opacity: 0.9

        MouseArea {
            anchors.fill: parent
            onClicked: container.opacity = 0
        }
    }

    ListModel {
        id: colorModel
        ListElement { colorimg: "images/customscreen/color-red.png"; code: "red" }
        ListElement { colorimg: "images/customscreen/color-blue.png"; code: "blue" }
        ListElement { colorimg: "images/customscreen/color-yellow.png"; code: "yellow" }
        ListElement { colorimg: "images/customscreen/color-purple.png"; code: "purple" }
        ListElement { colorimg: "images/customscreen/color-green.png"; code: "green" }
        ListElement { colorimg: "images/customscreen/color-orange.png"; code: "orange" }
        ListElement { colorimg: "images/customscreen/color-pink.png"; code: "pink" }
        ListElement { colorimg: "images/customscreen/color-grey.png"; code: "grey" }
    }

    ListView {
        id: colorView

        property string selectedColor: "red"

        anchors {
            top: parent.top
            horizontalCenter: parent.horizontalCenter
            topMargin: 50
        }

        width: 400
        height: 50
        interactive: false

        model: colorModel
        orientation: ListView.Horizontal

        delegate: Item {
            id: colorItem
            width: 50; height: 50

            Rectangle {
                id: colorSelector
                color: "white"
                opacity: colorView.selectedColor == code ? 1 : 0
                radius: 10
                width: 49
                height: 49
                anchors.centerIn: parent
            }

            Image {
                id: colorBox
                source: colorimg
                width: 43; height: 43
                anchors.centerIn: parent

            }

            MouseArea {
                anchors.fill: parent
                onClicked: {

                    colorView.selectedColor = code
                    dataLoader.loadParts(container.selectedCategory, code)
                }
            }

        }

    }

    Text {
        id: categoryName
        font {
            family: visual.fontHand
            pixelSize: 28
        }
        color: "white"
        horizontalAlignment: Text.AlignHCenter
        text: container.catName

        anchors {
            bottom: gridView.top
            bottomMargin: 20
            horizontalCenter: parent.horizontalCenter
        }
        smooth: true
    }

    Text {
        id: dragText
        font {
            family: visual.fontHand
            pixelSize: 24
        }
        color:"white"
        horizontalAlignment: Text.AlignHCenter
        text: "(you can drag the accessory to position it on your Monstar)"
        width: 400
        wrapMode: Text.Wrap
        opacity: container.selectedCategory == "accessories" ? 1 : 0

        anchors {
            bottom: parent.bottom
            bottomMargin: 50
            horizontalCenter: parent.horizontalCenter
        }
        smooth: true
    }

    GridView {
        id: gridView

        width: 404

        anchors {
            top: colorView.bottom
            topMargin: 80
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
        }

        model: dataLoader.partsModel
        cellWidth: 101
        cellHeight: 110
        interactive: false

        delegate: Image {
            id: item
            source: "images/customscreen/box-deselected.png"
            width: 96; height: 96
            smooth: true

            // part icon
            Image {
                id: partIcon
                width: 80; height: 80
                source: gridView.model.base + uri
                smooth: true
                anchors {
                    centerIn: parent
                    horizontalCenterOffset: -3
                    verticalCenterOffset: -5
                }

                scale: container.enlargeParts == true ? 1.2 : 1.0


            }

            MouseArea {
                anchors.fill: parent
                onPressed: {
                    item.source = "images/customscreen/box-selected.png"
                }
                onReleased: {
                    item.source = "images/customscreen/box-deselected.png"
                }
                onClicked: {
                    container.opacity = 0
                    container.partSelected(partIcon.source)
                }
            }


        }



    }
}
