import QtQuick 1.1

Item {
    id: container
    width: 480; height: 854
    state: "OPEN"

    property string nextPage

    signal doorClosed
    signal doorOpened

    Image {
        id: doorLeft
        width: 240; height: 854
        source: "images/transition/door-left.png"
        smooth: true
        anchors {
            verticalCenter: parent.verticalCenter

        }
    }

    Image {
        id: doorRight
        width: 280; height: 854
        source: "images/transition/door-right.png"
        smooth: true
        anchors {
            verticalCenter: parent.verticalCenter

        }

        Image {
            id: greenDot

            width: 19; height: 19
            state: "OFF"
            source: state == "ON" ? "images/transition/green-on.png" : "images/transition/green-off.png"
            anchors {
                centerIn: parent
                horizontalCenterOffset: -43
                verticalCenterOffset: 48
            }

        }

        Image {
            id: redDot
            width: 19; height: 19
            state: "ON"
            source: state == "ON" ? "images/transition/red-on.png" : "images/transition/red-off.png"
            anchors {
                centerIn: parent
                horizontalCenterOffset: -20
                verticalCenterOffset: 48
            }

        }

        Timer {
            id: dotTimer
            interval: 400
            running: true
            repeat: true
            onTriggered: {
                if (redDot.state == "ON") {
                    redDot.state = "OFF"
                    greenDot.state = "ON"
                } else {
                    redDot.state = "ON"
                    greenDot.state = "OFF"
                }
            }
        }
    }

    states: [
        State {
            name: "OPEN"
            PropertyChanges {
                target: doorLeft
                x: -240
            }

            PropertyChanges {
                target: doorRight
                x: 480
            }

        },

        State {
            name: "CLOSED"
            PropertyChanges {
                target: doorLeft
                x: 0
            }

            PropertyChanges {
                target: doorRight
                x: 200
            }
        }

    ]


    transitions: [
        Transition {
            id: doorClose
            from: "OPEN"
            to: "CLOSED"
            SequentialAnimation {
                NumberAnimation {
                    property: "x"
                    duration: 200
                    easing.type: Easing.InQuad
                }
                ScriptAction {script: container.doorClosed()}
            }

        },
        Transition {
            id: doorOpen
            from: "CLOSED"
            to: "OPEN"
            SequentialAnimation {
                NumberAnimation {
                    property: "x"
                    duration: 200
                    easing.type: Easing.InQuad
                }
                ScriptAction {script: container.doorOpened()}
            }

        }

    ]

    //    // For testing door animations only
    //    MouseArea {
    //        anchors.fill: parent
    //        onClicked: {
    //            if (container.state == "OPEN")
    //                container.state = "CLOSED"
    //            else
    //                container.state = "OPEN"
    //        }
    //    }
}
