import QtQuick 1.1
import com.nokia.meego 1.0

PageStackWindow {
    id: appWindow

    initialPage: mainPage//Qt.resolvedUrl("CompletionPage.qml")
    showStatusBar: false

    function closeDoor(page) {
        transitionDoor.nextPage = page
        transitionDoor.state = "CLOSED"
    }

    function openDoor() {
        transitionDoor.state = "OPEN"
    }

    MainPage {
        id: mainPage
    }

    StorageDatabase {
        id: storagedb
        appname: "Monstar"
        onInitialized: {
            console.log("Database initialized: " + Qt.md5(appname))
        }
    }

    // Splash screen
    Splash {
        id: splash
        width: 480; height: 854
        anchors.centerIn: parent

        Behavior on opacity { NumberAnimation { duration: 300 } }

        Timer {
            id: splashtimer
            interval: 2000
            onTriggered: splash.opacity = 0
            running: true
        }

    }

    Visual { id: visual }

    DataLoader {
        id: dataLoader
    }

    QueryDialog {
        id: infoDialog
        acceptButtonText: "OK"
        message: "Please give me a name!"


    }

    QueryDialog {
        id: aboutDialog

        icon: Qt.resolvedUrl("images/monstarmeego80.png")
        titleText: "Monstar 1.0"
        message: "A monster character creator for Nokia MeeGo devices.\n©2011 Nerd Attack!";
        acceptButtonText: "Close"

    }

    QueryDialog {
        id: returnDialog
        titleText: "Return to Main Menu"
        message: "Are you sure you want to discard this Monstar?"
        acceptButtonText: "YES"
        rejectButtonText: "Cancel"
        onRejected: returnDialog.close()
        onAccepted: pageStack.pop(null)

    }


    TransitionDoor {
        id: transitionDoor

        onDoorClosed: {
            if (nextPage != "") {
                transitionDelay.restart()
            }
        }

        // timer to delay pagestack transition so there's no lag
        Timer {
            id: transitionDelay
            interval: 400
            running: false
            onTriggered: {
                if (transitionDoor.nextPage == "CreatorPage.qml")
                    pageStack.push(Qt.resolvedUrl(transitionDoor.nextPage), {random: true})
                else
                    pageStack.push(Qt.resolvedUrl(transitionDoor.nextPage))
            }
        }


    }


}
